Module codec
rusty_
tarantool
0.3.2
Module codec
Module Items
Structs
Functions
Type Aliases
In rusty_
tarantool::
tarantool
rusty_tarantool
::
tarantool
Module
codec
Structs

Tarantool
Codec
Tokio framed codec for tarantool use it if you want manually set it on your tokio framed transport
Functions

parse_
headers
Type Aliases

Request
Id
Tarantool
Framed
Request