TarantoolResponse

Struct TarantoolResponse 

pub struct TarantoolResponse {
    pub code: u64,
    pub data: Bytes,
    pub sql_metadata: Option<Bytes>,
    pub sql_info: Option<Bytes>,
}
Tarantool response struct

use any decode method to decode tarantool response to custom struct by serde please look examples https://github.com/zheludkovm/RustyTarantool/tree/master/examples

Fields

code: u64data: Bytessql_metadata: Option<Bytes>sql_info: Option<Bytes>

Implementations

Source

impl TarantoolResponse

pub fn new_short_response(code: u64, data: Bytes) -> TarantoolResponse

pub fn new_full_response( code: u64, data: Bytes, sql_metadata: Option<Bytes>, sql_info: Option<Bytes>, ) -> TarantoolResponse

pub fn decode<'de, T>(self) -> Result<T>
where T: Deserialize<'de>,

decode tarantool response to any serder deserializable struct

pub fn decode_result_set<'de, T>(self) -> Result<Vec<T>>
where T: Deserialize<'de>,

decode tarantool response to any serder deserializable struct

pub fn decode_single<'de, T>(self) -> Result<T>
where T: Deserialize<'de>,

decode tarantool response to tuple wih one element and return this element

pub fn decode_pair<'de, T1, T2>(self) -> Result<(T1, T2)>
where T1: Deserialize<'de>, T2: Deserialize<'de>,

decode tarantool response to tuple of two elements

pub fn decode_trio<'de, T1, T2, T3>(self) -> Result<(T1, T2, T3)>
where T1: Deserialize<'de>, T2: Deserialize<'de>, T3: Deserialize<'de>,

decode tarantool response to three elements